==> camel-k-model-v1-6.2.0-sources.jar: io/fabric8/camelk/v1/SourceSpecFluent.java <==
package io.fabric8.camelk.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface SourceSpecFluent<A extends SourceSpecFluent<A>> extends Fluent<A>{
  public Boolean getCompression();
  public A withCompression(Boolean compression);
  public Boolean hasCompression();
  public String getContent();
  public A withContent(String content);
  public Boolean hasContent();
  public String getContentKey();
  public A withContentKey(String contentKey);
  public Boolean hasContentKey();
  public String getContentRef();
  public A withContentRef(String contentRef);
  public Boolean hasContentRef();
  public String getContentType();
  public A withContentType(String contentType);
  public Boolean hasContentType();
  public A addToInterceptors(Integer index,String item);
  public A setToInterceptors(Integer index,String item);
  public A addToInterceptors(java.lang.String... items);
  public A addAllToInterceptors(Collection<String> items);
  public A removeFromInterceptors(java.lang.String... items);
  public A removeAllFromInterceptors(Collection<String> items);
  public List<String> getInterceptors();
  public String getInterceptor(Integer index);
  public String getFirstInterceptor();
  public String getLastInterceptor();
  public String getMatchingInterceptor(Predicate<String> predicate);
  public Boolean hasMatchingInterceptor(Predicate<String> predicate);
  public A withInterceptors(List<String> interceptors);
  public A withInterceptors(java.lang.String... interceptors);
  public Boolean hasInterceptors();
  public String getLanguage();
  public A withLanguage(String language);
  public Boolean hasLanguage();
  public String getLoader();
  public A withLoader(String loader);
  public Boolean hasLoader();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public A addToPropertyNames(Integer index,String item);
  public A setToPropertyNames(Integer index,String item);
  public A addToPropertyNames(java.lang.String... items);
  public A addAllToPropertyNames(Collection<String> items);
  public A removeFromPropertyNames(java.lang.String... items);
  public A removeAllFromPropertyNames(Collection<String> items);
  public List<String> getPropertyNames();
  public String getPropertyName(Integer index);
  public String getFirstPropertyName();
  public String getLastPropertyName();
  public String getMatchingPropertyName(Predicate<String> predicate);
  public Boolean hasMatchingPropertyName(Predicate<String> predicate);
  public A withPropertyNames(List<String> propertyNames);
  public A withPropertyNames(java.lang.String... propertyNames);
  public Boolean hasPropertyNames();
  public String getRawContent();
  public A withRawContent(String rawContent);
  public Boolean hasRawContent();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A withCompression();
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/SourceSpecFluent.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface SourceSpecFluent<A extends SourceSpecFluent<A>> extends Fluent<A>{
  public Boolean getCompression();
  public A withCompression(Boolean compression);
  public Boolean hasCompression();
  public String getContent();
  public A withContent(String content);
  public Boolean hasContent();
  public String getContentKey();
  public A withContentKey(String contentKey);
  public Boolean hasContentKey();
  public String getContentRef();
  public A withContentRef(String contentRef);
  public Boolean hasContentRef();
  public String getContentType();
  public A withContentType(String contentType);
  public Boolean hasContentType();
  public A addToInterceptors(int index,String item);
  public A setToInterceptors(int index,String item);
  public A addToInterceptors(java.lang.String... items);
  public A addAllToInterceptors(Collection<String> items);
  public A removeFromInterceptors(java.lang.String... items);
  public A removeAllFromInterceptors(Collection<String> items);
  public List<String> getInterceptors();
  public String getInterceptor(int index);
  public String getFirstInterceptor();
  public String getLastInterceptor();
  public String getMatchingInterceptor(Predicate<String> predicate);
  public Boolean hasMatchingInterceptor(Predicate<String> predicate);
  public A withInterceptors(List<String> interceptors);
  public A withInterceptors(java.lang.String... interceptors);
  public Boolean hasInterceptors();
  public String getLanguage();
  public A withLanguage(String language);
  public Boolean hasLanguage();
  public String getLoader();
  public A withLoader(String loader);
  public Boolean hasLoader();
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public A addToPropertyNames(int index,String item);
  public A setToPropertyNames(int index,String item);
  public A addToPropertyNames(java.lang.String... items);
  public A addAllToPropertyNames(Collection<String> items);
  public A removeFromPropertyNames(java.lang.String... items);
  public A removeAllFromPropertyNames(Collection<String> items);
  public List<String> getPropertyNames();
  public String getPropertyName(int index);
  public String getFirstPropertyName();
  public String getLastPropertyName();
  public String getMatchingPropertyName(Predicate<String> predicate);
  public Boolean hasMatchingPropertyName(Predicate<String> predicate);
  public A withPropertyNames(List<String> propertyNames);
  public A withPropertyNames(java.lang.String... propertyNames);
  public Boolean hasPropertyNames();
  public String getRawContent();
  public A withRawContent(String rawContent);
  public Boolean hasRawContent();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A withCompression();
  
}
